@@ -29,8 +29,8 @@ class FileSelector : public ButtonSelector
 
 public:
     FileSelector(QString const& text, QWidget* parent = 0);
-    bool loadFiles(QString const& dir, QStringList const& patterns);
-    bool loadFiles(QString const& dir, QString const& pattern);
+    bool loadFiles(QString const& dir, QStringList const& patterns, bool stripType = false);
+    bool loadFiles(QString const& dir, QString const& pattern, bool stripType = false);
     bool importFile(QString const& dir, QString const& name,
                     QString const& pattern, bool add = true,
                     QString* addedFile = 0);
