@@ -23,16 +23,22 @@
 #include <QtCore/QStringList>
 #include <QtCore/QList>
 
+class QMediaPlayer;
+
 class MediaPlayer
 {
 public:
     enum Format {MP3, WAV, AAC, FORMAT_COUNT};
+    static void init();
     static bool play(QString const& file);
     static void getSupportedFormats(QList<QString>& formats);
     static QString getFormatPattern();
     static QStringList getFormatPatterns();
     static QString getSoundDir();
     static QString const& getLocalSoundDir();
+
+private:
+    static QMediaPlayer* getPlayer();
 };
 
 #endif
