@@ -29,7 +29,7 @@ public:
     enum Attribute {OPACITY, ATTRIBUTE_COUNT};
     OpacityEffect();
     virtual bool setAttribute(QString const& name, QString const& value);
-    virtual void apply(QGraphicsItem* item);
+    virtual void apply(GraphicsElement* item);
 
 private:
     QGraphicsOpacityEffect* effect_;
