@@ -31,7 +31,7 @@ class GraphicsScene;
 class Rectangle : public GraphicsElement
 {
 public:
-    enum Attribute {XPOS, YPOS, ZPOS, WIDTH, HEIGHT, COLOR, ATTRIBUTE_COUNT};
+    enum Attribute {XPOS, YPOS, ZPOS, VISIBLEWHEN, WIDTH, HEIGHT, COLOR, ATTRIBUTE_COUNT};
     Rectangle(Reader* reader);
     virtual bool setAttribute(QString const& name, QString const& value);
     virtual void addToScene(GraphicsScene* scene);
