@@ -54,11 +54,12 @@ namespace
                                                        "MAXSPEED", "AVGSPEED",
                                                        "UNIT", "SPEEDUNIT", "TIME", "DATE",
                                                        "POIDISTANCE", "ANGLE", "LATITUDE",
-                                                       "LONGITUDE"};
+                                                       "LONGITUDE", "ALTITUDE", "DISTANCEUNIT"};
 }
 
 TextElement::TextElement(Reader* reader): GraphicsElement(reader),
-data_(""), format_(""), align_("left"), timeFormat_("hh:mm"), dateFormat_("dd.MM.yyyy"), fontSize_(16), bold_(false), italic_(false),
+data_(""), format_(""), align_("left"), timeFormat_("hh:mm"),
+dateFormat_("dd.MM.yyyy"), fontSize_(16), bold_(false), italic_(false),
 uppercase_(false), letterSpacing_(0)
 {
     element_ = new QGraphicsTextItem();
@@ -286,6 +287,12 @@ void TextElement::replaceSpecialFields(QString& value)
         case LONGITUDE:
             replaceValue(value, f, handleEmpty(o->getLatestFix().longitude));
             break;
+        case ALTITUDE:
+            replaceValue(value, f, handleEmpty(o->getLatestFix().altitude));
+            break;
+        case DISTANCEUNIT:
+            replaceValue(value, f, o->getMeterUnit());
+            break;
         default:
             qDebug() << "Unknown field: " << f;
         }
@@ -315,7 +322,7 @@ QString TextElement::formatString(double val)
 
     if(format.isEmpty())
     {
-        format = "%.1lf";
+        format = "%.0lf";
     }
 
     QString result;
